@@ -15,20 +15,21 @@
 # specific language governing permissions and limitations
 # under the License.
 
+from typing import Optional
+
+from selenium.webdriver.chrome.options import Options
+from selenium.webdriver.chrome.service import Service
 from selenium.webdriver.chromium.webdriver import ChromiumDriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 
-from .options import Options
-from .service import Service
-
 
 class WebDriver(ChromiumDriver):
     """Controls the ChromeDriver and allows you to drive the browser."""
 
     def __init__(
         self,
-        options: Options = None,
-        service: Service = None,
+        options: Optional[Options] = None,
+        service: Optional[Service] = None,
         keep_alive: bool = True,
     ) -> None:
         """Creates a new instance of the chrome driver. Starts the service and
