@@ -17,10 +17,10 @@
 
 from typing import Optional
 
+from selenium.webdriver.chromium.options import ChromiumOptions
 from selenium.webdriver.chromium.remote_connection import ChromiumRemoteConnection
+from selenium.webdriver.chromium.service import ChromiumService
 from selenium.webdriver.common.driver_finder import DriverFinder
-from selenium.webdriver.common.options import ArgOptions
-from selenium.webdriver.common.service import Service
 from selenium.webdriver.remote.command import Command
 from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 
@@ -31,10 +31,10 @@ class ChromiumDriver(RemoteWebDriver):
 
     def __init__(
         self,
-        browser_name: Optional[str] = None,
-        vendor_prefix: Optional[str] = None,
-        options: ArgOptions = ArgOptions(),
-        service: Optional[Service] = None,
+        browser_name: str,
+        vendor_prefix: str,
+        options: Optional[ChromiumOptions] = None,
+        service: Optional[ChromiumService] = None,
         keep_alive: bool = True,
     ) -> None:
         """Creates a new WebDriver instance of the ChromiumDriver. Starts the
@@ -47,7 +47,9 @@ class ChromiumDriver(RemoteWebDriver):
          - service - Service object for handling the browser driver if you need to pass extra details
          - keep_alive - Whether to configure ChromiumRemoteConnection to use HTTP keep-alive.
         """
-        self.service = service
+
+        self.service = service if service else ChromiumService()
+        options = options if options else ChromiumOptions()
 
         finder = DriverFinder(self.service, options)
         if finder.get_browser_path():
