@@ -16,7 +16,6 @@
 # under the License.
 from enum import Enum
 from typing import Any
-from typing import Dict
 
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.common.options import ArgOptions
@@ -364,8 +363,8 @@ class Options(ArgOptions):
 
     def __init__(self) -> None:
         super().__init__()
-        self._options: Dict[str, Any] = {}
-        self._additional: Dict[str, Any] = {}
+        self._options: dict[str, Any] = {}
+        self._additional: dict[str, Any] = {}
 
     @property
     def options(self) -> dict:
